import bb.cascades 1.0
import BBM 1.0

Page {
    id: mainPage
    property bool showConversationInputArea: false
    property int ciaHeight      // used to put the proper padding on the items when the user moves from one to another
    property bool canScrollItems: true

    shortcuts: [
        Shortcut {
            //: Shortcut used to jump to previous picture
            key: qsTr("P") + Retranslate.onLanguageChanged

            objectName: "previousShortcut"
        },

        Shortcut {
            //: Shortcut used to jump to next picture
            key: qsTr("N") + Retranslate.onLanguageChanged

            objectName: "nextShortcut"
        },

        Shortcut {
            //: Shortcut used to view full picture
            key: qsTr("O") + Retranslate.onLanguageChanged

            objectName: "oViewShortcut"
        },

        Shortcut {
            //: Shortcut used to view full picture
            key: qsTr("I") + Retranslate.onLanguageChanged

            objectName: "iViewShortcut"
        }
    ]
    onShowConversationInputAreaChanged: {
        if (showConversationInputArea) {
            conversationInputAreaFadeIn.play()
        }
        else {
            conversationInputAreaFadeOut.play()
        }
    }

    content: Container {
        attachedObjects: [
            LayoutUpdateHandler {
                id: mainLayoutHandler
                objectName: "mainLayoutHandler"

                onLayoutFrameChanged: {
                    hScrollControl.height = layoutFrame.height
                }
            }
        ]

        layout: DockLayout {
        }

        HorizontalScrollControl {
            id: hScrollControl
            objectName: "hScrollControl"
            moveable: canScrollItems
        }
        
        ConversationInputArea {
            id: conversationInputArea
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Bottom
            visible: false

            attachedObjects: [
                LayoutUpdateHandler {
                    id: ciaLayoutHandler
                    objectName: "ciaLayoutHandler"

                    onLayoutFrameChanged: {
                        ciaHeight = layoutFrame.height
                    }
                }
            ]

            animations: [
                FadeTransition {
                    objectName: "conversationInputAreaFadeOut"
                    id: conversationInputAreaFadeOut
                    duration: 100
                    toOpacity: 0.0
                    
                    onEnded: {
                        conversationInputArea.visible = false
                    }
                },
                FadeTransition {
                    objectName: "conversationInputAreaFadeIn"
                    id: conversationInputAreaFadeIn
                    duration: 100
                    toOpacity: 1.0

                    onStarted: {
                        conversationInputArea.visible = true
                    }
                }
            ]
        }
    }
    actions: [
        ActionItem {
            imageSource: "asset:///images/GroupsGeneral/ic_comments.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            objectName: "showHideComments"
            id: showHideComments
            shortcuts: [
                Shortcut {
                    key: qsTr("C") + Retranslate.onLanguageChanged
                }
            ]
        },
        ActionItem {
            objectName: "TagAsFavorite"
            imageSource: "asset:///images/GroupsGeneral/ic_like.png"
            title: qsTr("Like Picture") + Retranslate.onLanguageChanged
        },
        ActionItem {
            objectName: "SavePicture"
            imageSource: "asset:///images/GroupsGeneral/ic_save.png"
            title: qsTr("Save Picture") + Retranslate.onLanguageChanged
        }/*, Add this once Voice Note support is added
        ActionItem {
            objectName: "AddVoiceNote"
        }*/
    ]
}
