import bb.cascades 1.0

Container {
    property bool isFavourite: false
    property bool showComments: false // leave this!
    property bool imageCaptionVisible: true
    property int nbComments: 55
    
    onShowCommentsChanged: {
        if (showComments) {
            quickFadeIn.play()
        }
        else {
            quickFadeOut.play()
        }
    }

    onImageCaptionVisibleChanged: {
        if (!imageCaptionVisible) {
            imageCaptionContainer.opacity = 0
        }
    }
    
    /*
     * These 2 StackLayouts are here only to force the picture to fill the entire space
    */
    layout: StackLayout {
        orientation: LayoutOrientation.TopToBottom
    }
    
    Container {
        
        layoutProperties: StackLayoutProperties {
            spaceQuota: 1
        }
        
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        
        Container {
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }

            layout: DockLayout {
            }
            
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            ImageView {
                id: picture
                objectName: "picture"
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
        
                attachedObjects: [
                    // ImageTracker used to be able to determine the size of the original image
                    ImageTracker {
                        id: tracker
                        objectName: "tracker"
                        onStateChanged: {
                            if (width > 0 && height > 0) {
                               picture.image = tracker.image
                            }
                        }
                    }
                ]
                scalingMethod: ScalingMethod.AspectFill
            }
        
            Container {
                id: favouriteImageContainer
                objectName: "favouriteImageContainer"
        
                // the image will be visible only if it's supposed to and once we have calculated the padding required
                visible: isFavourite
        
                layout: DockLayout {
                    id: favouriteImageContainerLayout
                }
                rightPadding: 10
                topPadding:   10
        
                verticalAlignment: VerticalAlignment.Top
                horizontalAlignment: HorizontalAlignment.Right
        
                ImageView {
                    imageSource: "asset:///images/GroupsGeneral/BBG_picture_star.png"
                }
            }
        
            Container {
                objectName: "imageNumberContainer"
                opacity: 1.0
                layout: DockLayout{
                    
                }
                //preferredHeight: 80
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Top
                
                animations: [
                    FadeTransition {
                        objectName: "numberFadeOut"
                        id: numberFadeOut
                        duration: 1000
                        fromOpacity: 1.0
                        toOpacity: 0.0
                    },
                    FadeTransition {
                        objectName: "numberFadeIn"
                        id: numberFadeIn
                        duration: 1000
                        fromOpacity: 0.0
                        toOpacity: 1.0
                    }
                ]
                
                ImageView {
                    imageSource: "asset:///images/GroupsGeneral/Picture_Number_BG.png"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                }
            
                Container {
                    topPadding: 0
                    leftPadding: 10
                    rightPadding:10
                    bottomPadding: 10
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    Label {
                        objectName: "imageNumber"
                        text: "WWWggg"
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Center
                        //textStyle.base: SystemDefaults.TextStyles.titleText
                        textStyle.fontSize: FontSize.Medium
                        textStyle.color: Color.create("#dadada")
                        topMargin: 0
                        bottomMargin: 0 
                    }
                }
            }
                
            Container {
                objectName: "commentListContainer"
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Bottom
                
                layout: DockLayout {
                }
                
                
                
                Container {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill

                    layout: StackLayout {
                        
                    }
                    Container {
                        objectName: "imageCaptionContainer"
                        id: imageCaptionContainer
                        visible: imageCaptionVisible || showComments || opacity > 0
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        layout: DockLayout {
                        }
                        animations: [
                            FadeTransition {
                                objectName: "quickFadeOut"
                                id: quickFadeOut
                                duration: 200
                                toOpacity: 0.0
                            },
                            FadeTransition {
                                objectName: "quickFadeIn"
                                id: quickFadeIn
                                duration: 200
                                toOpacity: 1.0
                            },
                            FadeTransition {
                                objectName: "fadeOut"
                                id: fadeOut
                                duration: 1000
                                fromOpacity: 1.0
                                toOpacity: showComments ? 1.0 : 0.0
                            },
                            FadeTransition {
                                objectName: "fadeIn"
                                id: fadeIn
                                duration: 1000
                                fromOpacity: showComments ? 1.0 : 0.0
                                toOpacity: 1.0
                            }
                        ]
                        Container {
                            background: Color.create("#121212")
                            opacity: 0.9
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Fill
                        }
	                    Container {
	
	                        layout: StackLayout {
	                            orientation: LayoutOrientation.LeftToRight                
	                        }
	                        horizontalAlignment: HorizontalAlignment.Fill
	                        verticalAlignment: showComments ? VerticalAlignment.Top : VerticalAlignment.Bottom
	                        
//	                        animations: [
//	                            FadeTransition {
//	                               // do nothing
//	                                objectName: "fadeOut"
//	                                id: fadeOut
//	                            },
//	                            FadeTransition {
//	                               // do nothing
//	                               objectName: "fadeIn"
//	                                id: fadeIn
//	                          }
//	                      ]
	
	                        Container {
	                            topPadding:     10
	                            leftPadding:    20
	                            rightPadding:   20
	                            bottomPadding:  10
	                            horizontalAlignment: HorizontalAlignment.Fill
	                            verticalAlignment: VerticalAlignment.Fill
	            
	                            layout: StackLayout {
	                                
	                            }
	                            layoutProperties: StackLayoutProperties
	                			{
	                				spaceQuota: 1
	                			}
	                            Label {
	                                objectName: "imageCaption"
	                                horizontalAlignment: HorizontalAlignment.Fill
	                                //verticalAlignment: VerticalAlignment.Center
	                                textStyle.fontSize: FontSize.Large
	                                textStyle.color: Color.White
                                    topMargin: 0 
	                                bottomMargin: 0
	                                multiline: true
	                                content.flags: TextContentFlag.Emoticons | TextContentFlag.ActiveText
	                                textFormat: TextFormat.Plain
	                            }
	                            Label {
	                                objectName: "postedBy"
	                                text: "posted by"
	                                topMargin: 0
	                                bottomMargin: 0
	                                horizontalAlignment: HorizontalAlignment.Fill
	                                textStyle.fontSize: FontSize.Small
	                                textStyle.color: Color.create("#dadada")
	                            }
	                        }
	
	                        Container {
	                            horizontalAlignment: HorizontalAlignment.Right
	                            verticalAlignment: VerticalAlignment.Center
	                            topPadding:     10
	                            leftPadding:    20
	                            rightPadding:   20
	                            bottomPadding:  10
	                            visible: nbComments > 0
	
	                            layout: DockLayout {
	
	                            }
	
	                            ImageView {
	                                horizontalAlignment: HorizontalAlignment.Fill
	                                verticalAlignment: VerticalAlignment.Fill
	
	                                //scalingMethod: ScalingMethod.Fill
	                                imageSource: "asset:///images/GroupsGeneral/GroupCommentBubble.png"
	                            }
	
	                            Container {
	                                layout: DockLayout {}
	                                //topPadding: 10
	                                leftPadding: 10
	                                rightPadding: 10
	                                bottomPadding: 15
	                                horizontalAlignment: HorizontalAlignment.Center
	                                verticalAlignment: VerticalAlignment.Center
	
	                                Label {
	                                    horizontalAlignment: HorizontalAlignment.Center
	                                    verticalAlignment: VerticalAlignment.Center
	
	                                    text: nbComments < 100 ? nbComments.toString() : "99+"
	                                    textStyle.base: SystemDefaults.TextStyles.BodyText
	                                    textStyle.color: Color.Black
	                                }
	                            }
	                        }
	
	                        ImageView {
	                            objectName: "voiceNote"
	                            imageSource: "asset:///images/MainScreen/ConversationPane/conversationPaneEmoticonButton.png"
	                            horizontalAlignment: HorizontalAlignment.Right
	                            verticalAlignment: VerticalAlignment.Center
	                            visible: false
	                        }
	                    }
	                }
            
                    Container {
                        objectName: "commentListViewContainer"
                        visible: showComments
                        layout: DockLayout {
                        }
	                    Container {
	                        background: _UIStyleManager.backgroundColor
                            opacity: 0.8
	                        horizontalAlignment: HorizontalAlignment.Fill
	                        verticalAlignment: VerticalAlignment.Fill
	                    }
	                    Container {
//	                        objectName: "commentListViewContainer"
//	                        visible: showComments
	                
	                        //background: Color.White
	                        horizontalAlignment: HorizontalAlignment.Fill
	                        verticalAlignment: VerticalAlignment.Fill
	                
	                        layout: StackLayout {
	                        }
	                        
	                        ImageView //horizontal line separator
	                        {
	                            objectName: "separator"
	                            horizontalAlignment: HorizontalAlignment.Fill
	                            verticalAlignment: VerticalAlignment.Top
	                            imageSource: "asset:///images/MainScreen/cells/content_horizontal_line.png"
	                            topMargin: 0
	                            leftMargin: 0
	                            rightMargin: 0
	                            bottomMargin: 0
	                        }
	
	                        Container {
	                            objectName: "NoCommentsContainer"
	                            horizontalAlignment: HorizontalAlignment.Center
	                            verticalAlignment: VerticalAlignment.Center

                                layout: DockLayout {
	                                
	                            }
	                            
	                            Label {
	                               objectName: "NoComments"
	                               visible: nbComments == 0
	                               text: qsTr("No Comments.") + Retranslate.onLanguageChanged
	                               textStyle.color: Color.LightGray
	                               textStyle.base: SystemDefaults.TextStyles.TitleText
	                               topMargin: 8; leftMargin: 8; rightMargin: 12; bottomMargin: 12;
	                               horizontalAlignment: HorizontalAlignment.Center
	                               verticalAlignment: VerticalAlignment.Center
	                            }
	                            
	                            ListView {
	                                objectName: "commentListView"
	                                horizontalAlignment: HorizontalAlignment.Fill
	                                verticalAlignment: VerticalAlignment.Fill
	                                layout: StackListLayout {
	                                    orientation: LayoutOrientation.TopToBottom
	                                }
	                            }
	                        }

                            Container {
                                id: ciaPaddingContainer
                                objectName: "ciaPaddingContainer"
                                visible: showComments
                            }
                        }
	                }
                }
            }
        }
    }
}
