import bb.cascades 1.0
import bb.extensions.cascades.tokenentry 1.0
import bb.device 1.0

Page
{
    id: root
    
    titleBar: TitleBar
    {
        objectName: "titleBar"
        title : qsTr("Invite") + Retranslate.onLanguageChanged

        dismissAction: ActionItem {
            objectName: "cancelAction"
            title: qsTr("Cancel") + Retranslate.onLanguageChanged
        }
        
        acceptAction: ActionItem {
            objectName: "sendAction"
            title: qsTr("Send") + Retranslate.onLanguageChanged
        }
    }
    
    actions: [
        ActionItem {
            imageSource: "asset:///images/QRCode.png"
            objectName: "barcodeAction"
            ActionBar.placement: ActionBarPlacement.OnBar
            title: qsTr("Scan to Invite") + Retranslate.onLanguageChanged
        }
    ]
    
    attachedObjects: [
        ActionItem {
            id: nfcAction
            objectName: "nfcAction"
            imageSource: "asset:///images/PendingInvites/NFCSmall.png"
            title: qsTr("Tap to Invite") + Retranslate.onLanguageChanged
        }
    ]
    
    onCreationCompleted: {
        if (nfcManager.nfcEnabled) {
            root.addAction(nfcAction, ActionBarPlacement.OnBar)
        }
    }

    shortcuts: [
        SystemShortcut {
            type: SystemShortcuts.Search

            onTriggered: {
                tokenEntry.requestFocus()
            }
        }
    ]

    content: ScrollView
	{
    	Container {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
			layout: StackLayout {
				orientation: LayoutOrientation.TopToBottom
			}

            TokenEntry
            {
	            property variant appScene: Application.scene
                
                id: tokenEntry
	            objectName: "tokenEntry"
                label: qsTr("To:") + Retranslate.onLanguageChanged
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
				
	            onAppSceneChanged: {
	                if (hwInfo.isPhysicalKeyboardDevice) {
	                	requestFocus()
	                }
	            }
				
				attachedObjects: [
				    HardwareInfo {
				        id: hwInfo
				    }
				]
            }
                
		    Container // message container which is a placehold for the SmartTextArea. NOTE: Dont remove this container!!
		    {
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
				objectName: "messageContainer"
		    
		        layout: StackLayout {
			        orientation: LayoutOrientation.LeftToRight
		        }
		        
		        rightPadding: _UILayoutManager.defaultPadding
			    leftPadding: _UILayoutManager.defaultPadding
			    bottomPadding: _UILayoutManager.defaultPadding
			    topPadding: _UILayoutManager.defaultPadding			        			        
		    } // end message container

    
            DefaultSeparator // horizontal line
		    {
                objectName: "horizontalLineAfterMessage"
                
				horizontalAlignment: HorizontalAlignment.Fill;
		    } // end horizontal line
		    
		    Container // category container
		    {
		        objectName: "categoryContainer"
		        
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
		    
		        layout: StackLayout {
			        orientation: LayoutOrientation.LeftToRight
		        }
    
		        rightPadding: _UILayoutManager.defaultPadding
			    leftPadding: _UILayoutManager.defaultPadding
			    bottomPadding: _UILayoutManager.defaultPadding
			    topPadding: _UILayoutManager.defaultPadding
			    
			    DropDown {
			        title: qsTr("Category") + Retranslate.onLanguageChanged
			        objectName: "category"
			        
			        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
			    }
		    } // end category container
		    
		    Container // security question container
		    {
		        objectName: "securityQuestionContainer"
		        visible: false
		            
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
		    
		        layout: StackLayout {
			        orientation: LayoutOrientation.TopToBottom
		        }
		        
		        rightPadding: _UILayoutManager.defaultPadding
       			leftPadding: _UILayoutManager.defaultPadding

       			 DropDown {
			        objectName: "securityDropDown"
			        visible: true
			        title: qsTr("Security Question") + Retranslate.onLanguageChanged
			        
		            horizontalAlignment: HorizontalAlignment.Fill
		            verticalAlignment: VerticalAlignment.Top
			        
			        Option {
			            text: qsTr("None") + Retranslate.onLanguageChanged
			            selected: true
			            
				        onSelectedChanged : {
			            	standardContainer.visible = !selected
				        }
			        }
			        
			        Option {
			            text: qsTr("Birthday") + Retranslate.onLanguageChanged
			            description: qsTr("Which month is my birthday in?") + Retranslate.onLanguageChanged

				        onSelectedChanged : {
				        	if (selected) {
				        		questionContainer.visible = false
				        		questionLabel.text = description
				            }
				        }
			        }
			        
			        Option {
			            text: qsTr("Pet") + Retranslate.onLanguageChanged
			            description: qsTr("What type of pet do I have?") + Retranslate.onLanguageChanged
			            
				        onSelectedChanged : {
				        	if (selected) {
				        		questionContainer.visible = false
				        		questionLabel.text = description
				            }
				        }
			        }
			        
			        Option {
			            text: qsTr("School") + Retranslate.onLanguageChanged
			            description: qsTr("What elementary school did I attend?") + Retranslate.onLanguageChanged
			            
				        onSelectedChanged :
				        {
				        	if (selected) {
				        		questionContainer.visible = false
				        		questionLabel.text = description
				            }
				        }
			        }
			        
			        Option {
			            text: qsTr("City") + Retranslate.onLanguageChanged
			            description: qsTr("Which city do I currently live in?") + Retranslate.onLanguageChanged
			            
				        onSelectedChanged : {
				        	if (selected) {
				        		questionContainer.visible = false
				        		questionLabel.text = description
							}
				        }
			        }

			        Option {
			            text: qsTr("Custom") + Retranslate.onLanguageChanged
			            
				        onSelectedChanged : {
				        	if (selected) {
				            	questionContainer.visible = true
				            	questionLabel.visible = false
				            }
				        }
			        }
			        
			        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
			    } // end security question dropdown
			    
			    
			    // ------------ SECURITY QUESTION CONTAINERS, these will be toggled on/off as necessary
			    Container // standard container (container with a label or input field for a question, and an input field for the answer)
			    {
			    	id: standardContainer
			    	visible: false
			    	objectName: "standardContainer"
			    	
					horizontalAlignment: HorizontalAlignment.Fill;
					verticalAlignment: VerticalAlignment.Fill;
			    
			        layout: StackLayout {
				        orientation: LayoutOrientation.TopToBottom
			        }
			        topPadding: _UILayoutManager.defaultPadding

            		Container // standard answer textfield container which is a placehold for the SmartTextArea. NOTE: Dont remove this container!!
			        {
						horizontalAlignment: HorizontalAlignment.Fill;
						verticalAlignment: VerticalAlignment.Fill;								
						
				    	objectName: "questionContainer"
				    	id: questionContainer
						
		            }				            
		            
			        Label { // question label
						horizontalAlignment: HorizontalAlignment.Fill;
						verticalAlignment: VerticalAlignment.Top;
					
						id: questionLabel
						objectName: "questionLabel"
						textStyle.color: _UIStyleManager.getSecondaryTextColor
						textStyle.base: SystemDefaults.TextStyles.SubtitleText

						topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
			        } // end pet label
			        
			        Container // standard answer textfield container which is a placehold for the SmartTextArea. NOTE: Dont remove this container!!
			        {
						horizontalAlignment: HorizontalAlignment.Fill;
						verticalAlignment: VerticalAlignment.Fill;
				        
				        objectName: "answerContainer"
				        id: answerContainer
				        
				        layout: StackLayout {
					        orientation: LayoutOrientation.TopToBottom
				        }
				        topPadding: _UILayoutManager.defaultPadding

            } // end standard answer textfield container
	    } // end standard container
	    
		// ------------ END SECURITY QUESTION CONTAINERS, these will be toggled on/off as necessary
				    
   	     } // end security question container
	} // end content
		} // end scrollview
	} // main container
