import bb.cascades 1.0

Container
{
    property string avatarUri: "asset:///images/defaultAvatar.png"
    property bool boldedContactName: false
    property string contactName
    property string descriptionText
    property bool descriptionFailed: false
    property bool isBusy: false
    property string messageStatusUri
    property bool showMessageStatus: false
    property string timeValue
    
    objectName: "rootContainer"
    property bool isHighlight: false
    
    layout: DockLayout {
    }    
    
    Container { //this is a placeholder for highlight imageview
        objectName: "highlightContainer"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: DockLayout {
        }
    }    
    
    Container { //this is a placeholder for pressed highlight imageview
        objectName: "pressedHighlightContainer"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: DockLayout {
        }
    }
    
    Container {
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
        Container {
            objectName: "touchSection"
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                layout: DockLayout {
                }
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                objectName: "avatarContainer"
                ImageView { // avatar
                    id: avatar
                    objectName: "avatar"
                    imageSource: avatarUri
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    preferredWidth: _UILayoutManager.defaultAvatarSize
                    preferredHeight: _UILayoutManager.defaultAvatarSize
                    scalingMethod: ScalingMethod.AspectFill
                    topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: -1
                    }
                } // end avatar
            }
            Container {
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                layout: DockLayout {
                }
                Container { // holds everything except avatar
                    layout: StackLayout {
                        orientation: LayoutOrientation.TopToBottom
                    }
                    rightPadding: 20
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    Container { // row 1: busy icon, name, time
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        }
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                            ImageView {
                                id: busyIconId
                                objectName: "busy"
                                imageSource: "asset:///images/message_states/busy.png"
                                horizontalAlignment: HorizontalAlignment.Center
                                verticalAlignment: VerticalAlignment.Center
                                visible: isBusy
                                scalingMethod: ScalingMethod.AspectFit
                                topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
                        } // end busy icon container
                        Container {
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Fill
                            preferredWidth: busyIconId.visible ? 0 : 40
                        }
                        Label { // name label
                            id: nameId
                            objectName: "name"
                            text: contactName
                            textStyle.fontSize: FontSize.Large
                            textStyle.fontWeight: boldedContactName ? FontWeight.Bold : FontWeight.Normal
                            textStyle.color: isHighlight ? _UIStyleManager.highlightTextColor : _UIStyleManager.primaryTextColor
                            content.flags: TextContentFlag.Emoticons | TextContentFlag.ActiveTextOff
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 1
                            }
                            horizontalAlignment: HorizontalAlignment.Left
                            verticalAlignment: VerticalAlignment.Center
                            topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
                        } // end name label
                        Label { // time label
                            id: timeId
                            objectName: "time"
                            text: timeValue
                            textStyle.fontSize: FontSize.XSmall
                            textStyle.color: isHighlight ? _UIStyleManager.highlightTextColor : _UIStyleManager.secondaryTextColor
                            horizontalAlignment: HorizontalAlignment.Right
                            verticalAlignment: VerticalAlignment.Center
                            topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
                        } // end time label
                    } // end row 1: busy icon, name, time
                    Container { // row 2: message status icon, last message/description,
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Bottom
                            Container { // message status container
                                layout: DockLayout {
                                }
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                ImageView {
                                    id: messageStatusIconId
                                    objectName: "messageStatus"
                                    horizontalAlignment: HorizontalAlignment.Center
                                    verticalAlignment: VerticalAlignment.Center
                                    visible: showMessageStatus
                                    imageSource: messageStatusUri
                                    scalingMethod: ScalingMethod.AspectFit
                                    topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
                                }
                            } // end message status container
                            Container {
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                preferredWidth: messageStatusIconId.visible ? 0 : 40
                            }
                            Container {
                                layout: DockLayout {
                                }
                                layoutProperties: StackLayoutProperties {
                                    spaceQuota: 1
                                }
	                            Label {
	                                id: descriptionId
	                                objectName: "description"
	                                text: descriptionText
	                                textStyle.color: isHighlight ? _UIStyleManager.highlightTextColor : _UIStyleManager.secondaryTextColor
	                                textStyle.fontSize: FontSize.Small
	                                content.flags: TextContentFlag.Emoticons | TextContentFlag.ActiveTextOff
	                                horizontalAlignment: HorizontalAlignment.Fill
	                                verticalAlignment: VerticalAlignment.Center
	                                textFormat: TextFormat.Plain
//	                                layoutProperties: StackLayoutProperties {
//	                                    spaceQuota: 1
//	                                }
	                                topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
	                            }
//	                            Label {
//                                    id: descriptionFailedId
//                                    objectName: "descriptionFailed"
//                                    text: qsTr("Failed:") + Retranslate.onLanguageChanged
//                                    textStyle.color: Color.Red
//                                    textStyle.fontSize: FontSize.Medium
//                                    content.flags: TextContentFlag.Emoticons
//                                    horizontalAlignment: HorizontalAlignment.Fill
//                                    verticalAlignment: VerticalAlignment.Center
//                                    visible: descriptionFailed
//                                    topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0
//                                }
                            }
                        }
                } // end hold everything except avatar
            }
        }
        DefaultSeparator {
        	horizontalAlignment: HorizontalAlignment.Fill
	    }
    }
}
