import bb.cascades 1.0

Page {
    property string categoryName: "DefaultCategoryName"
    property bool showEmptyContainer: false
    property bool unknownState: true

    actions: [
        ActionItem {
            imageSource: "file:///usr/share/icons/ic_invite_to_bbm.png"
            objectName: "inviteAction"
            title: qsTr("Invite to BBM") + Retranslate.onLanguageChanged
            id: inviteAction
            
            shortcuts: [
                Shortcut {
                    //: Shortcut used to invite a user to be part of the BBM list
                    key: qsTr("I") + Retranslate.onLanguageChanged
                }
            ]
        },

        ActionItem {
            imageSource: "file:///usr/share/icons/ic_start_bbm_chat.png"
            objectName: "chatAction"
            title: qsTr("Start Chat") + Retranslate.onLanguageChanged
            enabled: listView.visible
            id: startChatAction
            
            shortcuts: [
                SystemShortcut {
                    type: SystemShortcuts.CreateNew
                }
            ]
        },
        
        ActionItem {
            imageSource: "asset:///images/MainScreen/overflow/multichat.png"
            objectName: "multiChatAction"
            title: qsTr("Start Multiperson Chat") + Retranslate.onLanguageChanged
            enabled: listView.visible
        },
        ActionItem {
            imageSource: "asset:///images/MainScreen/overflow/broadcast.png"
            objectName: "broadcastAction"
            title: qsTr("Send Broadcast Message") + Retranslate.onLanguageChanged
            enabled: listView.visible
        },
        ActionItem {
            imageSource: "asset:///images/ic_add.png"
            objectName: "newCategoryAction"
            title: qsTr("Add Category") + Retranslate.onLanguageChanged
            enabled: listView.visible
        }
    ]

    shortcuts: [
        SystemShortcut {
            type: SystemShortcuts.JumpToBottom

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.Edit
            objectName: "editShortcut"
        },

        SystemShortcut {
            type: SystemShortcuts.NextSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.PreviousSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.Search

            onTriggered: {
                searchBar.textField.requestFocus()
            }
        },

        SystemShortcut {
            type: SystemShortcuts.JumpToTop

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        }
    ]

    content: Container {
        objectName: "stackContainer"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
        attachedObjects: [
            ActionItem {
                imageSource: "asset:///images/ic_add_caption.png"
                objectName: "renameCategory"
                title: qsTr("Rename \"%1\"").arg(categoryName) + Retranslate.onLanguageChanged
            },
            ActionItem {
                objectName: "moveToCategory"
                imageSource: "asset:///images/MainScreen/overflow/overflow_change_category.png"
                title: qsTr("Move Contacts") + Retranslate.onLanguageChanged
            },
            DeleteActionItem {
                objectName: "delCategory"
                title: qsTr("Delete Category") + Retranslate.onLanguageChanged
            }
        ]
        Container {
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }
            layout: DockLayout {
            }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.TopToBottom
                }
                visible: ! showEmptyContainer && ! unknownState
                DefaultSeparator {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Top
                }
                Container {
                    leftPadding: _UILayoutManager.defaultPadding
                    rightPadding: _UILayoutManager.defaultPadding
                    bottomPadding: _UILayoutManager.defaultPadding
                    topPadding: _UILayoutManager.defaultPadding
                    SearchBar {
                        id: searchBar
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        leftMargin: 0
                        rightMargin: 0
                        topMargin: 0
                        bottomMargin: 0
                    }
                }                
                DefaultSeparator {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Bottom
                }
                ListView {
                    id: listView
                    objectName: "listView"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    
                    attachedObjects: [
                        ListScrollStateHandler {
                            id: scrollHandler
                        }
                    ]
                    
                    leadingVisual: Container {
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        background: _UIStyleManager.containerColor
                        Container {
                            bottomPadding: _UILayoutManager.defaultPadding
                            leftPadding: _UILayoutManager.defaultPadding
                            rightPadding: _UILayoutManager.defaultPadding
                            topPadding: _UILayoutManager.defaultPadding
                            DropDown {
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Center
                                objectName: "dropDown"
                                title: qsTr("Contacts") + Retranslate.onLanguageChanged
                                topMargin: 0
                                leftMargin: 0
                                rightMargin: 0
                                bottomMargin: 0
                                Option {
                                    text: qsTr("All") + Retranslate.onLanguageChanged
                                    value: "OPTION_ALL"
                                    selected: true
                                }
                                Option {
                                    text: qsTr("Recently Updated") + Retranslate.onLanguageChanged
                                    value: "OPTION_RECENTLY_UPDATED"
                                }
                                Option {
                                    text: qsTr("Recently Added") + Retranslate.onLanguageChanged
                                    value: "OPTION_RECENTLY_ADDED"
                                }
                                Option {
                                    text: qsTr("Available") + Retranslate.onLanguageChanged
                                    value: "OPTION_AVAILABLE"
                                }
                            }
                        }                        
                        DefaultSeparator {
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Bottom
                        }
                    }
                    multiSelectHandler {
                        actions: [
                            ActionItem {
                                id: startChatMultiContacts
                                objectName: "startChatMultiContacts"
                                title: qsTr("Start Multiperson Chat") + Retranslate.onLanguageChanged
                                imageSource: "asset:///images/MainScreen/overflow/multichat.png"
                            },
                            ActionItem {
                                id: sendBroadcastMultiContacts
                                objectName: "sendBroadcastMultiContacts"
                                title: qsTr("Send Broadcast Message") + Retranslate.onLanguageChanged
                                imageSource: "asset:///images/MainScreen/overflow/broadcast.png"
                            },
                            ActionItem {
                                id: changeCategoriesMultiContacts
                                objectName: "changeCategoriesMultiContacts"
                                title: qsTr("Move Contacts") + Retranslate.onLanguageChanged
                                imageSource: "asset:///images/MainScreen/overflow/overflow_change_category.png"
                            },
                            DeleteActionItem {
                                id: deleteMultiContacts
                                objectName: "deleteMultiContacts"
                                title: qsTr("Delete Contacts") + Retranslate.onLanguageChanged
                            }
                        ]
                        status: qsTr("None selected") + Retranslate.onLanguageChanged
                    }
                    onSelectionChanged: {
                        var n = selectionList().length
                        multiSelectHandler.status = qsTr("+%n Contacts Selected", "", n) + Retranslate.onLanguageChanged
                        startChatMultiContacts.enabled = sendBroadcastMultiContacts.enabled = changeCategoriesMultiContacts.enabled = deleteMultiContacts.enabled = n > 0
                    }
                }
            }
            Container {
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                visible: showEmptyContainer && ! unknownState
                layout: StackLayout {
                }
                leftPadding: 80
                rightPadding: 80
                ImageView {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    imageSource: "asset:///images/emptyTabs/no_contacts_guy.png"
                }
                Label {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    multiline: true
                    textStyle.color: _UIStyleManager.primaryTextColor
                    textStyle.fontSize: FontSize.Large
                    textStyle.textAlign: TextAlign.Center
                    text: qsTr("You have no contacts.") + Retranslate.onLanguageChanged
                }                
                Button {
                    text: qsTr("Invite to BBM") + Retranslate.onLanguageChanged
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    onClicked: {
                        inviteAction.triggered()
                    }
                }
            }
        }
    }
}
