import bb.cascades 1.0

Container {
    id: root
    property real cropSize: 200
    
    property alias controlWidth: rootContainerLayoutHandler.layoutFrame.width
    property alias controlHeight: rootContainerLayoutHandler.layoutFrame.height
    
    property alias imageSource: imageView.imageSource   
    
    property alias viewableArea: scrollView.viewableArea    
    property alias contentScale: scrollView.contentScale
    
    
    function updateScrollViewContainerSize() {
        //calculate scrollview container size
        var newWidth = imageLayoutHandler.layoutFrame.width + (root.controlWidth - cropSize) / scrollView.contentScale;
       	var newHeight = imageLayoutHandler.layoutFrame.height + (root.controlHeight - cropSize) / scrollView.contentScale;
        imageContainer.implicitLayoutAnimationsEnabled = false;
        imageContainer.preferredWidth = newWidth;
        imageContainer.preferredHeight = newHeight;
                
        //calculate min zoom scale
        var minSize = Math.min(imageLayoutHandler.layoutFrame.width, imageLayoutHandler.layoutFrame.height);
        scrollView.implicitLayoutAnimationsEnabled = false;
        scrollView.scrollViewProperties.minContentScale = root.cropSize / minSize;
       // console.log("width= "+cropContainer.preferredWidth+" height = "+ cropContainer.preferredHeight);
    }
    function resetToCenter() {
        //scrollView.zoomToPoint(imageContainerLayoutHandler.layoutFrame.width * 0.5 - cropSize * 0.5, imageContainerLayoutHandler.layoutFrame.height * 0.5 - cropSize * 0.5, 1.0, ScrollAnimation.None);
        scrollView.zoomToPoint(imageContainerLayoutHandler.layoutFrame.width * 0.5, imageContainerLayoutHandler.layoutFrame.height * 0.5, 1.0, ScrollAnimation.None);
        console.log("resetToCenter");
    }

    layout: DockLayout {
    }
    attachedObjects: [
        LayoutUpdateHandler {
            id: rootContainerLayoutHandler
        }
    ]
    implicitLayoutAnimationsEnabled: false
    
    background: Color.create("#A0A0A0")
    ScrollView {
        id: scrollView
        
        scrollViewProperties.pinchToZoomEnabled: true
        scrollViewProperties.maxContentScale: 4
		scrollViewProperties.scrollMode: ScrollMode.Both
        verticalAlignment: VerticalAlignment.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        implicitLayoutAnimationsEnabled: false
        minWidth: cropSize
        minHeight: cropSize
        
        ContainerNoImplicit {
            layout: DockLayout {
            }
            id: imageContainer
            objectName:"imageContainer"
                        
            implicitLayoutAnimationsEnabled: false
            attachedObjects: [
                LayoutUpdateHandler {
                    id: imageContainerLayoutHandler
                }
            ]
            ImageView {
                id: imageView
                objectName:"cropControlImage"
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                minWidth: cropSize
                minHeight: cropSize
                implicitLayoutAnimationsEnabled: false
                
                scalingMethod: ScalingMethod.AspectFit
                onImageSourceChanged: {
                    imageLayoutHandler.counter = 0;
                }
                attachedObjects: [
                    LayoutUpdateHandler {
                        id: imageLayoutHandler
                        property real counter: 0
                        onLayoutFrameChanged: {
                            if (counter == 0) {
                                console.log("onLayoutFrameChanged: [" + layoutFrame.x + ", " + layoutFrame.y + ", " + layoutFrame.width + ", " + layoutFrame.height + "]");
                                root.updateScrollViewContainerSize();
                                counter ++;
                            } else if (counter == 1) {
                                root.resetToCenter();
                                counter ++;
                            }
                        }
                    }
                ]
            }
        }
	    onViewableAreaChanging: {
            updateScrollViewContainerSize();
        }
        onViewableAreaChanged: {
            updateScrollViewContainerSize();
        }
    }
    ContainerNoImplicit {
        id: cropContainer
        property string cropColor: '#80000000'
        touchPropagationMode: TouchPropagationMode.None
         verticalAlignment: VerticalAlignment.Fill
         horizontalAlignment: HorizontalAlignment.Fill
  
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
        ContainerNoImplicit {
            background: Color.create(cropContainer.cropColor)
            horizontalAlignment: HorizontalAlignment.Fill

            layout: DockLayout {
            }
            preferredHeight: (root.controlHeight - root.cropSize) / 2
        }
        ContainerNoImplicit {
            clipContentToBounds: false
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            horizontalAlignment: HorizontalAlignment.Fill

            preferredHeight: root.cropSize
            ContainerNoImplicit {
                background: Color.create(cropContainer.cropColor)
                verticalAlignment: VerticalAlignment.Fill
 
                preferredWidth: (root.controlWidth - root.cropSize) / 2
                layout: DockLayout {
                }
            }
            ContainerNoImplicit {
                clipContentToBounds: false
                verticalAlignment: VerticalAlignment.Fill

                preferredWidth: root.cropSize
                layout: DockLayout {
                }
            }
                
            ContainerNoImplicit {
                clipContentToBounds: false
                background: Color.create(cropContainer.cropColor)
                verticalAlignment: VerticalAlignment.Fill

                preferredWidth: (root.controlWidth - root.cropSize) / 2
                layout: DockLayout {
                }
            }
        }
        //bottom row
        ContainerNoImplicit {
            clipContentToBounds: false
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            horizontalAlignment: HorizontalAlignment.Fill
           
            preferredHeight: (root.controlHeight - root.cropSize) / 2
            ContainerNoImplicit {
                clipContentToBounds: false
                background: Color.create(cropContainer.cropColor)
                verticalAlignment: VerticalAlignment.Fill

                preferredWidth: (root.controlWidth - root.cropSize) / 2
                layout: DockLayout {
                }
            }
            ContainerNoImplicit {
                background: Color.create(cropContainer.cropColor)
                clipContentToBounds: false
                verticalAlignment: VerticalAlignment.Fill

                preferredWidth: root.cropSize
                layout: DockLayout {
                }
            }
            ContainerNoImplicit {
                clipContentToBounds: false
                background: Color.create(cropContainer.cropColor)
                verticalAlignment: VerticalAlignment.Fill

                preferredWidth: (root.controlWidth - root.cropSize) / 2
                layout: DockLayout {
                }
            }
        }
    }
}
