import bb.cascades 1.0

Page {
    property int numReceived: 0
    property int numSent: 0
    property int numRecommended: 0
    property bool showList: (numReceived > 0 && toggleView.selectedIndex == 0) || (numSent > 0 && toggleView.selectedIndex == 1) || (numRecommended > 0 && toggleView.selectedIndex == 2)

    shortcuts: [
        SystemShortcut {
            type: SystemShortcuts.JumpToBottom

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.Edit
            objectName: "editShortcut"
        },

        SystemShortcut {
            type: SystemShortcuts.NextSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.PreviousSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.JumpToTop

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        }
    ]

    actions: [
        ActionItem {
            imageSource: "file:///usr/share/icons/ic_invite_to_bbm.png"
            objectName: "inviteAction"
            id: inviteAction
            title: qsTr("Invite to BBM") + Retranslate.onLanguageChanged
            
            shortcuts: [
                SystemShortcut {
                    type: SystemShortcuts.CreateNew
                },

                Shortcut {
                    //: Shortcut used to invite a user to be part of the BBM list
                    key: qsTr("I") + Retranslate.onLanguageChanged
                }
            ]
        }
    ]
    content: Container {
        objectName: "stackContainer"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
        DefaultSeparator {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Top
        }
            Container {
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                leftPadding: _UILayoutManager.defaultPadding
                rightPadding: _UILayoutManager.defaultPadding
                topPadding: _UILayoutManager.defaultPadding
                bottomPadding: _UILayoutManager.defaultPadding
                background: _UIStyleManager.containerColor
                SegmentedControl {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    id: toggleView
                    objectName: "toggleView"
                    Option {
                        //: This is the text value for received pending invites on the segmented control
                        text: qsTr("Received") + Retranslate.onLanguageChanged
                        selected: true
                    }
                    Option {
                        //: This is the text value for received outgoing invites on the segmented control
                        text: qsTr("Sent") + Retranslate.onLanguageChanged
                    }
                    Option {
                        //: This is the text value for received outgoing invites on the segmented control
                        text: qsTr("Suggested") + Retranslate.onLanguageChanged
                    }
                    topMargin: 0
                    leftMargin: 0
                    rightMargin: 0
                    bottomMargin: 0
                }
        }
        DefaultSeparator {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Bottom
                }
        Container {
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }
            layout: DockLayout {
            }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                objectName: "noInvitesContainer"
                id: noInvitesContainer
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                visible: ! showList
                bottomPadding: _UILayoutManager.defaultPadding
                ImageView {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    imageSource: "asset:///images/emptyTabs/no_pending_guy.png"
                }
                Label {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    objectName: "emptyLabel"
                    textStyle.color: _UIStyleManager.primaryTextColor
                    textStyle.fontSize: FontSize.Large
                    textStyle.textAlign: TextAlign.Center
                    multiline: true
                    leftMargin: 0
                    rightMargin: 0
                    bottomMargin: 0
                    topMargin: 0
                    text: {
                        if (toggleView.selectedIndex == 0) {
                            //: This is the text to display when there are no pending received invitations
                            qsTr("No new invitations.") + Retranslate.onLanguageChanged
                        } else if (toggleView.selectedIndex == 1) {
                            //: This is the text to display when there are no sent invitations
                            qsTr("No pending invitations.") + Retranslate.onLanguageChanged
                        } else {
                            //: This is the text to display when there are no sent invitations
                            qsTr("No recommended contacts.") + Retranslate.onLanguageChanged                     
                        }
                    }
                }
                Button {
                    text: qsTr("Invite to BBM") + Retranslate.onLanguageChanged
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    onClicked: {
                        inviteAction.triggered()
                    }
                }
            }
            ListView {
                id: listView
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                layout: StackListLayout {
                    orientation: LayoutOrientation.TopToBottom
                    headerMode: ListHeaderMode.Sticky
                }
                objectName: "listView"
                visible: showList
            }
        }
    }
}
