import bb.cascades 1.0

Page
{
    property string messageText: ""
    property string inviteeName: ""
    property string inviteePin: ""
    property string timestamp: ""
    property bool enableActions: false
    
    titleBar: TitleBar {
        title : qsTr("Invitation to BBM") + Retranslate.onLanguageChanged
    }
    
    actions: [
        ActionItem {
            objectName: "acceptAction"
            imageSource: "file:///usr/share/icons/ic_accept.png"
            title: qsTr("Accept") + Retranslate.onLanguageChanged
            ActionBar.placement: ActionBarPlacement.OnBar
            enabled: enableActions
        },
                
        ActionItem {
            objectName: "ignoreAction"
            imageSource: "asset:///images/GroupsGeneral/ic_ignore.png"
            title: qsTr("Ignore") + Retranslate.onLanguageChanged
            ActionBar.placement: ActionBarPlacement.OnBar
            enabled: enableActions
        }
    ]
    
    content: Container
    {
    		layout: StackLayout {
    			orientation: LayoutOrientation.TopToBottom
    		}
    	
    	    Container // drop shadow dock layout
    	    {
    	    	layout: DockLayout {}
    	    	
    		    Container // invite cell container
    		    {
    		        layout: StackLayout {
    		            orientation: LayoutOrientation.LeftToRight
    		        }
    		        
		            horizontalAlignment: HorizontalAlignment.Fill
		            verticalAlignment: VerticalAlignment.Fill
    		        
    		        ImageView {
    		            imageSource: "asset:///images/defaultAvatar.png"
    		            preferredWidth: _UILayoutManager.defaultAvatarSize
                        preferredHeight: _UILayoutManager.defaultAvatarSize
                        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    		            
		            	horizontalAlignment:HorizontalAlignment.Left; 
		            	verticalAlignment:VerticalAlignment.Top;  	            
    		        }
    		        
    			    Container
    			    {
			            leftPadding: _UILayoutManager.defaultPadding
                        rightPadding: _UILayoutManager.defaultPadding

                        layoutProperties: StackLayoutProperties {
    			            spaceQuota: 1;
    			        }
    			        horizontalAlignment: HorizontalAlignment.Fill
    			        verticalAlignment: VerticalAlignment.Center
    		
    		            Container {
    		                layout: StackLayout {
                          orientation: LayoutOrientation.LeftToRight
                      }
    			        Label
    			        {
    			            layoutProperties: StackLayoutProperties {
                       spaceQuota: 1
                   }
    			            textStyle.color: _UIStyleManager.primaryTextColor
    			            textStyle.fontSize: FontSize.Large
    			            text: inviteeName
                            content.flags: TextContentFlag.Emoticons | TextContentFlag.ActiveTextOff
                            
    			            horizontalAlignment: HorizontalAlignment.Fill
    			            verticalAlignment: VerticalAlignment.Center
    			            topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
                        }
                        Label {
                            textStyle.color: _UIStyleManager.secondaryTextColor
                            textStyle.fontSize: FontSize.Small
                            text: inviteePin;
                            content.flags: TextContentFlag.ActiveTextOff

                            horizontalAlignment: HorizontalAlignment.Right
                            verticalAlignment: VerticalAlignment.Center
                            topMargin: 0
                            leftMargin: 0
                            rightMargin: 0
                            bottomMargin: 0
                        }
                    }
    			        
    			        Label {
    			            textStyle.color: _UIStyleManager.secondaryTextColor
                            textStyle.fontSize: FontSize.Small
    			            text: timestamp
    			            
    			            horizontalAlignment: HorizontalAlignment.Fill
    			            verticalAlignment: VerticalAlignment.Center
    			            topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    			        }
    			    }
    		    } // end invite cell container
    		    
    	    	ImageView
    	    	{
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Top
                    imageSource: "asset:///images/title_bar/core_titlebar_dropdown_shadow_top.png"
                }
    	    } // end drop shadow dock layout
    	    
    	    ImageView // horizontal line
    	    {
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Top;
    	
    	        imageSource: "asset:///images/MainScreen/cells/horizontal_line.png"
    	        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    	    } // end horizontal line
    	    
    	    Container // invitation message container
    	    {
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
    	    
    	        layout: StackLayout {
    		        orientation: LayoutOrientation.LeftToRight
    		    }
		        rightPadding: _UILayoutManager.defaultPadding
                leftPadding: _UILayoutManager.defaultPadding
                topPadding: 15
			    bottomPadding: 70
    	    
    		    Label
    		    {
    		        textStyle.color: _UIStyleManager.primaryTextColor
                    textStyle.fontSize: FontSize.Medium
    		        horizontalAlignment: HorizontalAlignment.Fill
    		        verticalAlignment: VerticalAlignment.Fill
    		        
    		        multiline: true
    		        text: messageText
    		        content.flags: TextContentFlag.Emoticons | TextContentFlag.ActiveText
    		        
    		        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    		    }
    	    } // end invitation message container
    	    
    	    ImageView // horizontal line
    	    {
				horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Top;
    	
    	        imageSource: "asset:///images/MainScreen/cells/horizontal_line.png"
    	        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    	    } // end horizontal line
    	    
    	    Container // category container
    	    {
    	        objectName: "categoryContainer"
    			layoutProperties: StackLayoutProperties {
    				spaceQuota: 1
    			}
    			horizontalAlignment: HorizontalAlignment.Fill;
				verticalAlignment: VerticalAlignment.Fill;
    	    
    	        layout: StackLayout {
    		        orientation: LayoutOrientation.LeftToRight
    		    }
    		    
		        rightPadding: _UILayoutManager.defaultPadding
                leftPadding: _UILayoutManager.defaultPadding
                bottomPadding: 10
			    topPadding: _UILayoutManager.defaultPadding

                DropDown {
    				objectName: "category"
    				title: qsTr("Category") + Retranslate.onLanguageChanged
    		        
		            horizontalAlignment: HorizontalAlignment.Fill
		            verticalAlignment: VerticalAlignment.Top
    		        topMargin: 0; leftMargin: 0; rightMargin: 0; bottomMargin: 0;
    		    }
    	    } // end category container
    	}
}
