import bb.cascades 1.0

Page {
    property bool showEmptyContainer: false
    property bool unknownState: true

    shortcuts: [
        SystemShortcut {
            type: SystemShortcuts.JumpToBottom

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.Edit
            objectName: "editShortcut"
        },

        SystemShortcut {
            type: SystemShortcuts.NextSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.End, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.PreviousSection

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        },

        SystemShortcut {
            type: SystemShortcuts.JumpToTop

            onTriggered: {
                listView.scrollToPosition(ScrollPosition.Beginning, ScrollAnimation.Default)
            }
        }
    ]

    actions: [
        ActionItem {
            imageSource: "file:///usr/share/icons/ic_invite_to_bbm.png"
            objectName: "inviteAction"
            id: inviteAction
            title: qsTr("Invite to BBM") + Retranslate.onLanguageChanged

            shortcuts: [
                Shortcut {
                    //: Shortcut used to invite a user to be part of the BBM list
                    key: qsTr("I") + Retranslate.onLanguageChanged
                }
            ]
        }
    ]
    content: Container {
        objectName: "stackContainer"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
        DefaultSeparator {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Top
        }
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }
            layout: DockLayout {
            }
            ListView {
                // TODO: This is a temporary workaround which should be removed
                // after cascade team fixes PR255332
                // When the label in ListItemComponent is clicked , the ListView
                // is also triggered. Therefore, we need to add the innerTap
                // boolean to track whether the touch event is already handled 
                // by the ListItemComponent.
                property bool innerTap: false
                
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                id: listView
                visible: ! showEmptyContainer && ! unknownState
                objectName: "listView"
                leadingVisual: Container {
                    layout: DockLayout {
                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                    visible: listView.visible
                    Container {
                        leftPadding: _UILayoutManager.defaultPadding
                        rightPadding: _UILayoutManager.defaultPadding
                        topPadding: _UILayoutManager.defaultPadding
                        bottomPadding: _UILayoutManager.defaultPadding
                        background: _UIStyleManager.containerColor
                        DropDown {
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Center
                            objectName: "dropDown"
                            title: qsTr("Updates") + Retranslate.onLanguageChanged
                            topMargin: 0
                            leftMargin: 0
                            rightMargin: 0
                            bottomMargin: 0
                        } // end dropdown
                    }
                    DefaultSeparator {
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Bottom
                    }
                }
            }
            Container {
                visible: showEmptyContainer && ! unknownState
                layout: StackLayout {
                }
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                leftPadding: 80
                rightPadding: 80
                bottomPadding: 30
                ImageView {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    preferredWidth: 181
                    preferredHeight: 181
                    scalingMethod: ScalingMethod.AspectFit
                    imageSource: "asset:///images/emptyTabs/no_updates.png"
                }
                Label {
                    multiline: true
                    text: qsTr("No updates.") + Retranslate.onLanguageChanged
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    textStyle.color: _UIStyleManager.primaryTextColor
                    textStyle.fontSize: FontSize.Large
                    textStyle.textAlign: TextAlign.Center
                    topMargin: 0
                    leftMargin: 0
                    rightMargin: 0
                    bottomMargin: 0
                }
            }
        }
    }
}
