import bb.cascades 1.0

Page
{
    property bool addContactsOnTap: true
    property bool allowCallsOverMobile: true
    property bool autoRecordVoiceNotes: false
    property bool saveChatHistory: false
    property bool receiveCalls: true
    property bool showAvatarsOnBubbles: true
    property bool showCountryTime: false
    property bool showListeningTo: false
    property bool showAppUpdates: true
    property bool showMusicUpdates: true
    property bool showSecurityQuestion: false
    property bool showVideoChatCamera: true
    property string buildIdValue: "BuildID"
    property bool enableTestMode: false
    property bool showTestModeContainer: false
    property bool showProfiler: false
    property bool showVideoChatSettings: false
    property string layoutGridMode: "grid"
    property bool enableClearChatHistory: true
    property bool enableMobileCalls: false
    
    titleBar: TitleBar {
        title: qsTr("BBM Settings") + Retranslate.onLanguageChanged
    }

    content: Container
    {
        touchPropagationMode: TouchPropagationMode.PassThrough
        
        layoutProperties: StackLayoutProperties {
            spaceQuota: 1
        }

        ScrollView
        {
            scrollViewProperties {
                scrollMode: ScrollMode.Vertical
            }

            Container // main container
            {
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill

                SettingPairToggle
                {
                    topPadding: 30
                    objectName: "showListeningTo"
                    toggleButtonInstance.objectName: "showListeningToToggleBtn"
                    enableMode: showListeningTo
                    labelText: qsTr("Show What I'm Listening To") + Retranslate.onLanguageChanged
                }

                SettingPairToggle
                {
                    objectName: "showLocationTimezoneToggle"
                    toggleButtonInstance.objectName: "showLocationTimezoneToggleBtn"
                    enableMode: showCountryTime
                    labelText: qsTr("Show My Country and Time") + Retranslate.onLanguageChanged
                }

                DefaultSeparator {
		        	horizontalAlignment: HorizontalAlignment.Fill
			    }
                
                Container
                {
	                SettingPairToggle
	                {
	                    objectName: "allowMobileCalls"
	                    toggleButtonInstance.objectName: "allowMobileCallsToggleBtn"
	                    enableMode: allowCallsOverMobile
	                    labelText: qsTr("Allow BBM Calls over mobile networks") + Retranslate.onLanguageChanged
	                    enabled: enableMobileCalls
	                }
	                
	                DefaultSeparator {
			        	horizontalAlignment: HorizontalAlignment.Fill
				    }
	                
	                visible: showVideoChatSettings
                }
                Container {
                    leftPadding: 20
                    rightPadding: 20
                    topPadding: 20
                    DropDown {
                        leftMargin: 0
                        rightMargin: 0
                        topMargin: 0
                        bottomMargin: 0
                        verticalAlignment: VerticalAlignment.Center
                        objectName: "contactLayout"
                        title: qsTr("Contacts Layout") + Retranslate.onLanguageChanged
                        Option {
                            text: qsTr("Grid") + Retranslate.onLanguageChanged
                            value: "grid"
                            selected: value == layoutGridMode
                        }
                        Option {
                            text: qsTr("List") + Retranslate.onLanguageChanged
                            value: "list"
                            selected: value == layoutGridMode
                        }
                    }
                }
                SettingPairToggle
                {
                    objectName: "chatBubbleHeadersToggle"
                    toggleButtonInstance.objectName: "chatBubbleHeadersToggleBtn"
                    enableMode: showAvatarsOnBubbles
                    labelText: qsTr("Show Display Pictures in Chats") + Retranslate.onLanguageChanged
                }
                
                SettingPairToggle
                {
                    objectName: "autoRecordVoiceNotes"
                    toggleButtonInstance.objectName: "autoRecordVoiceNotesBtn"
                    enableMode: autoRecordVoiceNotes
                    labelText: qsTr("Automatically Record Voice Notes") + Retranslate.onLanguageChanged
                }
                
                SettingPairToggle
                {
                    objectName: "nfcToggle"
                    toggleButtonInstance.objectName: "nfcToggleBtn"
                    enableMode: addContactsOnTap
                    labelText: qsTr("Add Contacts On Tap") + Retranslate.onLanguageChanged
                    visible: nfcManager.nfcEnabled
                }

                SettingPairToggle
                {
                    objectName: "showSecurityQuestion"
                    toggleButtonInstance.objectName: "showSecurityQuestionToggleBtn"
                    enableMode: showSecurityQuestion
                    labelText: qsTr("Security Question on Invites") + Retranslate.onLanguageChanged
                }
                
                DefaultSeparator {
		        	horizontalAlignment: HorizontalAlignment.Fill
			    }
                
                SettingPairToggle
                {
                    
                    objectName: "musicUpdateToggle"
                    toggleButtonInstance.objectName: "musicUpdateToggleBtn"
                    enableMode: showMusicUpdates
                    labelText: qsTr("Music Status Updates") + Retranslate.onLanguageChanged
                }
                
                /*
                SettingPairToggle
                {
                    objectName: "appUpdateToggle"
                    toggleButtonInstance.objectName: "appUpdateToggleBtn"
                    enableMode: showAppUpdates
                    labelText: qsTr("App Status Updates") + Retranslate.onLanguageChanged
                }
                */
                
                DefaultSeparator {
		        	horizontalAlignment: HorizontalAlignment.Fill
			    }
                
                SettingPairToggle
                {
                    objectName: "saveChatHistoryToggle"
                    toggleButtonInstance.objectName: "saveChatHistoryToggleButton"
                    enableMode: saveChatHistory
                    labelText: qsTr("Save Chat History") + Retranslate.onLanguageChanged
                }

                SettingPairButton
                {
                    buttonInstance.objectName: "clearChatHistoryButton"
                    buttonInstance.enabled: enableClearChatHistory
                    labelText: qsTr("Chat History") + Retranslate.onLanguageChanged
                    buttonLabel: qsTr("Delete") + Retranslate.onLanguageChanged
                }

                DefaultSeparator {
		        	horizontalAlignment: HorizontalAlignment.Fill
			    }

                SettingPairButton
                {
                    buttonInstance.objectName: "blockedContactListButton"
                    labelText: qsTr("Blocked Contacts") + Retranslate.onLanguageChanged
                    buttonLabel: qsTr("Edit") + Retranslate.onLanguageChanged
                }

                Container { // row 12
                    objectName: "testModeContainer"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Top
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    leftPadding: 20
                    rightPadding: 20
                    bottomPadding: 10
                    topPadding: 10
                    visible: showTestModeContainer
                    Label {
                        layoutProperties: StackLayoutProperties {
                            spaceQuota: 1
                        }
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Center
                        visible: false
                        multiline: true
                        objectName: "testModeLabel"
                        id: testModeLabel
                        textStyle.base: SystemDefaults.TextStyles.BodyText
                        topMargin: 0
                        bottomMargin: 0
                        leftMargin: 0
                        rightMargin: 0
                        text: "Test Mode"
                    }

                    ToggleButton {
                        layoutProperties: StackLayoutProperties {
                            spaceQuota: 2
                        }
                        horizontalAlignment: HorizontalAlignment.Right
                        verticalAlignment: VerticalAlignment.Center
                        visible: false
                        objectName: "testModeToggle"
                        id: testModeToggle
                        checked: enableTestMode
                    }
                    Button {
                        layoutProperties: StackLayoutProperties {
                            spaceQuota: 2
                        }
                        horizontalAlignment: HorizontalAlignment.Right
                        verticalAlignment: VerticalAlignment.Center
                        visible: showProfiler
                        objectName: "dumpProfilerData"
                        text: "Dump Profiler Data"
                        id: dumpProfilerData
                    } // end row 12
                }
            } // end main container
        }

        function showTestMode(show) {
            testModeLabel.visible = show
            testModeToggle.visible = show
        }
    }
}